@@ -59,6 +59,6 @@ class AOI(BaseModel):
         return self._aoi_data["features"][0]["geometry"]
 
     def make_top_left(self):
-        xs = [x[0] for x in self.aoi._coords]
-        ys = [y[1] for y in self.aoi._coords]
+        xs = [x[0] for x in self._coords]
+        ys = [y[1] for y in self._coords]
         return min(xs), max(ys)
